import * as react_jsx_runtime from 'react/jsx-runtime';
import * as React from 'react';

interface DataTransformer {
    serialize: (object: any) => any;
    deserialize: (object: any) => any;
}
interface HydrationStreamContext<TShape> {
    id: string;
    stream: {
        /**
         * **Server method**
         * Push a new entry to the stream
         * Will be ignored on the client
         */
        push: (...shape: Array<TShape>) => void;
    };
}
interface HydrationStreamProviderProps<TShape> {
    children: React.ReactNode;
    /**
     * Optional transformer to serialize/deserialize the data
     * Example devalue, superjson et al
     */
    transformer?: DataTransformer;
    /**
     * **Client method**
     * Called in the browser when new entries are received
     */
    onEntries: (entries: Array<TShape>) => void;
    /**
     * **Server method**
     * onFlush is called on the server when the cache is flushed
     */
    onFlush?: () => Array<TShape>;
    /**
     * A nonce that'll allow the inline script to be executed when Content Security Policy is enforced
     */
    nonce?: string;
}
declare function createHydrationStreamProvider<TShape>(): {
    Provider: (props: {
        children: React.ReactNode;
        /**
         * Optional transformer to serialize/deserialize the data
         * Example devalue, superjson et al
         */
        transformer?: DataTransformer | undefined;
        /**
         * **Client method**
         * Called in the browser when new entries are received
         */
        onEntries: (entries: Array<TShape>) => void;
        /**
         * **Server method**
         * onFlush is called on the server when the cache is flushed
         */
        onFlush?: (() => Array<TShape>) | undefined;
        /**
         * A nonce that'll allow the inline script to be executed when Content Security Policy is enforced
         */
        nonce?: string | undefined;
    }) => react_jsx_runtime.JSX.Element;
    context: React.Context<HydrationStreamContext<TShape>>;
};

export { type HydrationStreamProviderProps, createHydrationStreamProvider };
